;------------   Exemple d'application avec un PIC : Un clignotant    ---------------

; Titre : Clignotant
; Date : 01 MARS 2010
; Auteur : P.M
; PIC utilis : PIC 16 F 88
; On ralise un clignotant sur la broche RB0  d' un PIC 16 F 88 le quartz est de 4 
; Mhz , on effectue une tempo environ gale  0.2 seconde. 
; un bouton marche sur le port A permet de lancer le clignotant  une 1 re frquence. 
; un 2 me bouton permet d' obtenir une 2 eme frquence
; un 3 me bouton permet d' obtenir une 3 eme frquence

;------------   Directive d' assemblage pour MPLAB   ---------------

	list	p=16f88
	#include p16f88.inc
    errorlevel -302


;------------   Dfinition des constantes   ---------------

#define inter0	0		; bouton marche
#define inter1	1		; bouton 1 ere frquence
#define inter2	2		; bouton 2 eme frquence

;-----------  Dfinitions de macro pour les banks ---------------

bank0	macro
	bcf STATUS,RP0
	bcf STATUS,RP1
	endm	

bank1	macro
	bsf STATUS,RP0
	bcf STATUS,RP1
	endm
					
;------------   Dfinition des registres temporaires   ---------------

retard1      	EQU        0x20      ; le registre temporaire retard1 se trouve  l' adresse 20
tp2	  	EQU        0x21      ; le registre temporaire tp2 se trouve  l' adresse 21
retard2      	EQU        0x22      ; le registre temporaire retard1 se trouve  l' adresse 22
memo	  	EQU        0x23      ; le registre temporaire memo se trouve  l' adresse 23
	
;------------   Init des ports A et B   ---------------

          ORG     0       
          
  	    bank1
	    MOVLW 0x07                         ; on met 07 dans le registre W
          MOVWF CMCON                        ; on met 07 dans le registre CMCON les comparateurs sont 
	    				     		   ; inhibs
          clrf ANSEL				   ; inhibition des entres analogiques

          BSF STATUS,5				; on met  1 le 5eme bit du registre status pour accder
    							;  la 2eme page mmoire ( pour trisa et trisb )

          MOVLW 0x00                           ; on met 00 dans le registre W
          MOVWF TRISB                         ; on met 00 dans le port B il est programm en sortie

          MOVLW 0x3F                           ; on met 3F dans le registre W
          MOVWF TRISA                         ; on met 3F dans le port A il est programm en entre
	  
          BCF STATUS,5		; on remet  0 le 5eme bit du registre status pour accder	
				;  la 1eme page mmoire 

;------------   raz de la led et du registre memo  ---------------


         MOVLW  0x00              ; on met 00 dans le registre W
         MOVWF  PORTB          ; on met W sur le port B ( led )
         MOVWF  memo            ; on met W dans le registre memo
         MOVWF tp2                 ; on met W dans le registre tp2

;------------   Programme principal   ---------------

debut
 	
	 btfss PORTA,inter0	; interrupteur 0 ( marche ) appuy ? si oui on continu sinon 
	        		              ;va  debut
	 goto debut 

; -------------------- Test des inters ----------------------
				
         btfss PORTA,inter1	; interrupteur 1 ( freq 1 ) appuy ? si non on va  suite
         goto suite
         MOVLW 0x01             ; on met 01 dans le registre W
         MOVWF tp2               ; on met W dans le registre tp2 

suite	 
         btfss PORTA,inter2     ; interrupteur 2 ( freq 2 ) appuy ? si oui va  freq2 			
         goto suite2
         MOVLW 0x02             ; on met 02 dans le registre W
         MOVWF tp2               ; on met W dans le registre tp2 
suite2

         MOVLW 0xFF            ; on met ff dans le registre W
         MOVWF retard1         ; on met W dans le registre retard1 ( 1 ere frquence )
         MOVWF retard2         ; on met W dans le registre retard2 ( 1 ere frquence )
         
         MOVLW 0xAA            ; on met AA dans le registre W ( 2 eme frquence )
         btfsc tp2,0	             ; on test le bit 0 de tp2 si = 1 alors on saute la prochaine instruction
         MOVWF retard2         ; sinon on met W dans le registre retard2 ( 2 ere frquence )

         MOVLW 0x55            ; on met 55 dans le registre W ( 3 eme frquence )
         btfsc tp2,1	            ; on test le bit 1 de tp2 si = 1 alors on saute la prochaine instruction
         MOVWF retard2         ; sinon on met W dans le registre retard2 ( 3 ere frquence )

         COMF memo,F 	; On effectue le complment du registre memo et 
         MOVF memo,W           ; on met le resultat dans W	
         MOVWF  PORTB         ; on met W sur le port B ( leds )
         
	
         CALL  tempo              ; on appel la temporisation
         
         GOTO  debut             ; retour au dbut du programme


;------------   Programme de temporisation    ---------------

tempo
          DECFSZ retard1,F       ; on dcrmente retard1 et on saute la prochaine instruction si 
          GOTO  tempo             ; le registre retard1 = 0 sinon retour  tempo

          movlw 0xFF		 ; on recharge retard1
          movwf retard1

          DECFSZ retard2,F       ; on dcrmente retard2 et on saute la prochaine instruction si 
          GOTO  tempo             ; le registre retard2 = 0 sinon retour  tempo


          movlw 0x00	  	 ; On met 0 dans TP2
          movwf tp2
	  
          RETURN                 ; retour au programme principal aprs l 'instruction CALL

          END
 






